﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Data.Entity;
using System.Data.Entity.ModelConfiguration;
using System.Data.Entity.Database;
using System.ComponentModel.DataAnnotations;

namespace CodeFirst
{
	public class Customer
	{
		public int ID { get; set; }
		[MaxLength(50)]
		public string Name { get; set; }
	}

	[Table("NewOrders")]
	public class Order
	{
		public int ID { get; set; }
		[Column(Name = "OD")]
		public DateTime OrderDate { get; set; }
		public DateTime? ShippingDate { get; set; }
		public AddressInfo ShippingAddress { get; set; }
		public int CustomerID { get; set; }
		public Customer Customer { get; set; }
		public ICollection<OrderDetail> Details { get; set; }
		[Required]
		public string FullAddress
		{
			get { return String.Format("{0}-{1}-{2}-{3}", ShippingAddress.Address, ShippingAddress.City, ShippingAddress.ZipCode, ShippingAddress.Country); }
		}
	}

	public class AddressInfo
	{
		public string Address { get; set; }
		public string City { get; set; }
		public string ZipCode { get; set; }
		public string Country { get; set; }
	}

	public class OrderDetail
	{
		public int ID { get; set; }
		public int OrderID { get; set; }
		public int ProductID { get; set; }
		public int UnitPrice { get; set; }
		public int Quantity { get; set; }
	}

	public class OrderContext : DbContext
	{
		public DbSet<Customer> Customers { get; set; }
		public DbSet<Order> Orders { get; set; }
		public DbSet<OrderDetail> OrderDetails { get; set; }
		protected override void OnModelCreating(ModelBuilder modelBuilder)
		{
			modelBuilder.Entity<Order>().Property(p => p.OrderDate).HasColumnName("OD");
			modelBuilder.Entity<Order>().Ignore(p => p.FullAddress);
			modelBuilder.Entity<Customer>().HasKey(c => c.ID);
		}
	}

}
